/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for ST STM32G431RB_Nucleo board
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED_BIT          (5)  // LD2, PA5, Green, High is on

#define RCC_BASE_ADDR    (0x40021000u)
#define RCC_AHB2ENR      (*(volatile unsigned int*)(RCC_BASE_ADDR + 0x4Cu))
#define RCC_LEDPORT_BIT  (1)

#define GPIOA_BASE_ADDR  (0x48000000u)
#define GPIOA_MODER      (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x00u))
#define GPIOA_ODR        (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x14u))
#define GPIOA_BSSR       (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x18u))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  RCC_AHB2ENR |= (1u << 0);               // Enable GPIO Port A clock
  GPIOA_MODER &= ~(3u << (LED_BIT *  2));  // Reset mode; sets port to input
  GPIOA_MODER |=  (1u << (LED_BIT *  2));  // Set to output mode
  GPIOA_BSSR  &= ~(1u << (LED_BIT + 16));  // Initially clear LEDs
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIOA_BSSR |= (1u << LED_BIT);  // Switch on LED
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIOA_BSSR |= (1u << (LED_BIT + 16));  // Switch off LED
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    if (GPIOA_ODR & (1u << LED_BIT)) {
      GPIOA_BSSR |= (1u << (LED_BIT + 16));  // Switch off LED
    } else {
      GPIOA_BSSR |= (1u << LED_BIT);       // Switch on LED
    }
  }
}

/*************************** End of file ****************************/
